==> ceph-mon-2025.1.0+3334b7425.tgz: ceph-mon/CHANGELOG.md <==
# Release notes

## 2025.1.0-63

### New Features

- Update apparmor values to use security_context instead of annotations.
- Add support for runtimeClassName and priorityClassName

## 2025.1.0

- 0.1.0 Initial Chart
- 0.1.1 Change helm-toolkit dependency to >= 0.1.0
- 0.1.2 Enable shareProcessNamespace in mon daemonset
- 0.1.3 Run mon container as ceph user
- 0.1.4 Uplift from Nautilus to Octopus release
- 0.1.5 Add Ceph CSI plugin
- 0.1.6 Fix python3 issue for util scripts
- 0.1.7 remove deprecated svc annotation tolerate-unready-endpoints
- 0.1.8 Use full image ref for docker official images
- 0.1.9 Remove unnecessary parameters for ceph-mon
- 0.1.10 Export crash dumps when Ceph daemons crash
- 0.1.11 Correct mon-check executing binary and logic
- 0.1.12 Fix Ceph checkDNS script
- 0.1.13 Helm 3 - Fix Job labels
- 0.1.14 Update htk requirements
- 0.1.15 Prevent mon-check from removing mons when down temporarily
- 0.1.16 Correct Ceph Mon Check Ports
- 0.1.17 Skip monmap endpoint check for missing mons
- 0.1.18 Move ceph-mgr deployment to the ceph-mon chart
- 0.1.19 Add a post-apply job to restart mons after mgrs
- 0.1.20 Consolidate mon_endpoints discovery
- 0.1.21 Change configmap names to be based on release name
- 0.1.22 Correct configmap names for all resources
- 0.1.23 Release-specific ceph-template configmap name
- 0.1.24 Prevents mgr SA from repeated creation
- 0.1.25 Allow for unconditional mon restart
- 0.1.26 Added OCI registry authentication
- 0.1.27 Update all Ceph images to Focal
- 0.1.28 Document the use of mon_allow_pool_size_one
- 0.1.29 Update Ceph to 17.2.6
- 0.1.30 Use Helm tookkit functions for Ceph probes
- 0.1.31 Add Rook Helm charts for managing Ceph with Rook
- 0.1.32 Update Rook to 1.12.5 and Ceph to 18.2.0
- 0.1.33 Update Ceph images to Jammy and Reef 18.2.1
- 0.1.34 Update Ceph images to patched 18.2.2 and restore debian-reef repo
- 0.1.35 Use seprate secrets for CSI plugin and CSI provisioner
- 0.1.36 Use quay.io/airshipit/kubernetes-entrypoint:latest-ubuntu_focal by default
- 0.1.37 Update Chart.yaml apiVersion to v2
- 2024.2.0 Update version to align with the Openstack release cycle

## 2024.2.0

Before 2024.2.0 all the OpenStack-Helm charts were versioned independently.
Here we provide all the release notes for the chart for all versions before 2024.2.0.

==> ceph-mon-2025.1.2+5742204b6.tgz: ceph-mon/CHANGELOG.md <==
# Release notes

## 2025.1.0-82

- Upgrade Ceph to 19.2.3 and adjust the ceph-mgr liveness probe to account
  for a new asok status query handler that returns an empty dictionary.

### New Features

- Update apparmor values to use security_context instead of annotations.
- Add support for runtimeClassName and priorityClassName

## 2025.1.0

- 0.1.0 Initial Chart
- 0.1.1 Change helm-toolkit dependency to >= 0.1.0
- 0.1.2 Enable shareProcessNamespace in mon daemonset
- 0.1.3 Run mon container as ceph user
- 0.1.4 Uplift from Nautilus to Octopus release
- 0.1.5 Add Ceph CSI plugin
- 0.1.6 Fix python3 issue for util scripts
- 0.1.7 remove deprecated svc annotation tolerate-unready-endpoints
- 0.1.8 Use full image ref for docker official images
- 0.1.9 Remove unnecessary parameters for ceph-mon
- 0.1.10 Export crash dumps when Ceph daemons crash
- 0.1.11 Correct mon-check executing binary and logic
- 0.1.12 Fix Ceph checkDNS script
- 0.1.13 Helm 3 - Fix Job labels
- 0.1.14 Update htk requirements
- 0.1.15 Prevent mon-check from removing mons when down temporarily
- 0.1.16 Correct Ceph Mon Check Ports
- 0.1.17 Skip monmap endpoint check for missing mons
- 0.1.18 Move ceph-mgr deployment to the ceph-mon chart
- 0.1.19 Add a post-apply job to restart mons after mgrs
- 0.1.20 Consolidate mon_endpoints discovery
- 0.1.21 Change configmap names to be based on release name
- 0.1.22 Correct configmap names for all resources
- 0.1.23 Release-specific ceph-template configmap name
- 0.1.24 Prevents mgr SA from repeated creation
- 0.1.25 Allow for unconditional mon restart
- 0.1.26 Added OCI registry authentication
- 0.1.27 Update all Ceph images to Focal
- 0.1.28 Document the use of mon_allow_pool_size_one
- 0.1.29 Update Ceph to 17.2.6
- 0.1.30 Use Helm tookkit functions for Ceph probes
- 0.1.31 Add Rook Helm charts for managing Ceph with Rook
- 0.1.32 Update Rook to 1.12.5 and Ceph to 18.2.0
- 0.1.33 Update Ceph images to Jammy and Reef 18.2.1
- 0.1.34 Update Ceph images to patched 18.2.2 and restore debian-reef repo
- 0.1.35 Use seprate secrets for CSI plugin and CSI provisioner
- 0.1.36 Use quay.io/airshipit/kubernetes-entrypoint:latest-ubuntu_focal by default
- 0.1.37 Update Chart.yaml apiVersion to v2
- 2024.2.0 Update version to align with the Openstack release cycle

## 2024.2.0

Before 2024.2.0 all the OpenStack-Helm charts were versioned independently.
Here we provide all the release notes for the chart for all versions before 2024.2.0.
